| Title: | Population Genetics Statistics for Selective Sweep |
|---|---|
| Description: | Selective Sweep can be calculated by five significant Population Genetics Statistics such as "Pi", "Wattersons_theta", "Tajima_D", "Kelly_ZnS" and "Omega" Statistics in specified chromosomal region. It has been developed by using the concept of "Kern" and "Schrider" (2018)<doi:10.1534/g3.118.200262>. |
| Authors: | Abhik Sarkar [aut, cre], Dwijesh Chandra Mishra [aut], Dipro Sinha [aut], Saikath Das [aut], Krishna Kumar Chaturvedi [aut], Shashi Bhushan Lal [aut], Sanjeev Kumar [aut], Ranjit Kumar Paul [aut], Girish Kumar Jha [aut], Neeraj Budhlakoti [aut], Md Yeasin [aut] |
| Maintainer: | Abhik Sarkar <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.0 |
| Built: | 2026-05-17 06:47:37 UTC |
| Source: | https://github.com/cran/GenePopStats |
Title GenePopStats: Population Genetics Statistics for Selective Sweep
GenePopStats(vcf_file, window_size, step_size)GenePopStats(vcf_file, window_size, step_size)
vcf_file |
Enter the path to VCF File |
window_size |
Length of the genomic region |
step_size |
Length of slide in the window in forward direction |
Results are being obtained as a matrix containing 5 Population Summary Statistics such as "Pi", "Wattersons_theta", "Tajima_D", "Kelly_ZnS" and "Omega" Statistics subdivided into windows as specified chromosomal region
path<-system.file("exdata", "ExampleVCF.vcf", package = "GenePopStats") GenePopStats(path, 20, 10)path<-system.file("exdata", "ExampleVCF.vcf", package = "GenePopStats") GenePopStats(path, 20, 10)